<?php

namespace Drupal\jsonapi_links\EventSubscriber;

use Drupal\jsonapi\ResourceResponse;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

class ResponseSubscriber implements EventSubscriberInterface {
  public function onResponse(ResponseEvent $event) {
    $response = $event->getResponse();
    // First we check if we have an JSON:API response
    if (strtolower($response->headers->get('content-type', 'unknown')) !== 'application/vnd.api+json') {
      return;
    }

    $content = $response->getContent();
    $json = json_decode($content);

    // 2nd check if we have an JSON:API JSON
    if (!isset($json->jsonapi)) {
      return;
    }

    // This check shall prevent, that the meta.links.me info is removed.
    $jsonapi_base_path = \Drupal::getContainer()->getParameter('jsonapi.base_path');
    if ($event->getRequest()->getPathInfo() === $jsonapi_base_path) {
      return;
    }

    // Check if we shall do anything at all
    $config = \Drupal::config('jsonapi_links.settings');

    if (!$config->get('remove_links')) {
      return;
    }

    $this->removeLinks($json);

    $response->setContent(json_encode($json));
    $event->setResponse($response);
  }

  protected function removeLinks(&$data) {
    if (is_scalar($data)) {
      return;
    }

    if (is_object($data)) {
      unset($data->links);

      foreach (get_object_vars($data) as $name => $attribute) {
        $this->removeLinks($data->$name);
      }

      return;
    }

    if (is_array($data)) {
      foreach ($data as &$item) {
        $this->removeLinks($item);
      }
    }
  }

  public static function getSubscribedEvents() {
    $events[KernelEvents::RESPONSE][] = ['onResponse', 112];
    return $events;
  }

}
